SpanKind

Enum SpanKind 

#[non_exhaustive]
pub enum SpanKind { Internal, Client, Server, Producer, Consumer, }
The kind of a span in distributed tracing.

This enum represents the different types of spans that can be created in distributed tracing, including internal operations, client requests, server requests, message production, and message consumption.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Internal

The default span kind, representing an internal operation within the library.



Client

The span represents a client request.



Server

The span represents a server request.



Producer

The span represents a message being produced. This is typically used for messaging systems where a message is sent to a queue or topic.



Consumer

The span represents a message being consumed. This is typically used for messaging systems where a message is received from a queue or topic.