SpanStatus

Enum SpanStatus 

#[non_exhaustive]
pub enum SpanStatus { Unset, Error { description: String, }, }
The status of a span.

This enum represents the possible statuses of a span in distributed tracing. It can be either Unset, indicating that the span has not been set to any specific status, or Error, which contains a description of the error that occurred during the span’s execution

Note that OpenTelemetry defines an Ok status but that status is reserved for application and service developers, so libraries should never set it.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Unset

The span has not been set to any specific status.



Error

The span has encountered an error, with a description of the error.

Fields

description: String

A description of the error that occurred during the span’s execution.